//! Contains definitions of global variables, functions and enumerated types.
/*! \file test.h
    The HOOPS/Stream Toolkit utilizes several global enumerated types.  The functions which black box support for writing
    and reading HOOPS Stream Files are also global, and are defined in BStream.h
*/



//! Codes which can be either passed to various toolkit functions, or indicate the result of a toolkit function call 
/*! \enum TK_Status
    Various toolkit functions can take arguments which control processing behavior.  Most functions also provide a return
    value of type TK_Status to indicate success, failure or other information about processing status.
*/
enum TK_Status {
    TK_Normal   = 0, /*!< When used as input: read through to a 'termination' code.  When used as output:  function call succeeded */        
    TK_Error    = 1, /*!< A return value; function call failed */ 
    TK_Pause    = 2, /*!< An input value; instructs toolkit to stop reading at a 'pause' code */
    TK_Single   = 3, /*!< An input value; instructs toolkit to stop reading after the first object is completed */
    TK_Pending  = 4, /*!< A return value; the toolkit is waiting for (needs) more data */
    TK_Revisit  = 5, /*!< A return value; interpret function succeeded, but we will run it through again later */
    TK_Complete = 6, /*!< A return value; processing is complete */
    TK_Version  = 7, /*!< A return value; version mis-match detected, processing halted */
    TK_NotFound = 8, /*!< A return value; failed to find a match */
    TK_Abort    = 9  /*!< A return value; non-fatal error. callback requested stop, or fall back to plan B (internal) */
};


//! Options which control how the HOOPS Stream File is generated
/*! \enum TK_File_Write_Options
	An HSF file has a variety of properties, and the toolkit utilizes default logic when generating a file.  
    This enumerated type gives the user high-level control over file compression, tagging and content.  These
	options are set by calling BStreamFileToolkit::SetWriteFlags

*/
enum TK_File_Write_Options {
    TK_Suppress_LOD               = 0x00000002, /*!< No LODS are exported, only the original shells are written out (single pass); implicitly disables dictionary */
    TK_Full_Resolution_Vertices   = 0x00000004, /*!< Data fidelity is required for geometry; this causes the full single-precision floating point information to be exported; does not affect LODs or lossless compression of connectivity information */
    TK_Full_Resolution_Normals    = 0x00000008, /*!< Data fidelity is required for normals; as in above description of TK_Full_Resolution_Points */
    TK_Full_Resolution = (TK_Full_Resolution_Vertices|TK_Full_Resolution_Normals), /*!< for convenience, a combination of 2 other options. */
    TK_First_LOD_Is_Bounding_Box  = 0x00000010, /*!< Adds a new LOD to represent the lowest resolution of objects, which is a bounding box representation */
    TK_Force_Tags                 = 0x00000020, /*!< All appropriate objects (geometries,segments,includes) will be tagged */
    TK_Disable_Priority_Heuristic = 0x00000040, /*!< Disables organization of multiresolution objects according to heuristic cost/benifit.  */
    TK_Disable_Global_Compression = 0x00000100, /*!< Inline lossless compression will not be used */
    TK_Disable_Instancing         = 0x00000200, /*!< Object instancing will not be used */
    TK_Generate_Dictionary        = 0x00000400, /*!< Enables random-access by creation of the file dictionary */
    TK_Connectivity_Compression   = 0x00000800, /*!< Enables connectivity compression  */
    TK_Disable_Tristrips          = 0x00001000, /*!< Disables triangle strips, and the triangulation it requires, in shells.  Incurs a heavy read-time computational cost.  */
    TK_Disable_Compound_Primitives = 0x00002000, /*!< Disables the use of OpcodeHandlers that encode multiple primitives (since they cannot be properly tagged) */
    TK_Global_Quantization         = 0x00004000  /*!< Causes any required quantization to be global (bbox of scene) instead of local (bbox of individual geometry) .  Regardless of this flag, however, local quantization applies until the first TKE_Bounding_Info.  HStreamFiletoolkit sends a TKE_Bounding_Info automatically, but BStreamFiletoolkit does not. */
};